New Version of LibreOffice Added

2020-03-08 Thread noreply
We added a new version of LibreOffice to the list.
Please add this version to your LibreOffice extension release(s), if it is 
(they are) compatible with this version.

You could do this on your release(s). Go to the release of your project and 
choose the command 'edit' from the menu bar. Go to the section 'compatible with 
versions of LibreOffice' and mark  the checkbox for the new version of 
LibreOffice.

Kind regards,

The LibreOffice Extension and Template Site Administration Team
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


Templates Section: New Version of LibreOffice Added

2020-03-08 Thread noreply
We added a new version of LibreOffice to the list.
 Please add this version to your LibreOffice template release(s), if it is 
(they are) compatible with this version.

You could do this on your release(s). Go to the release of your project and 
choose the command 'edit' from the menu bar. Go to the section 'compatible with 
versions of LibreOffice' and mark the checkbox for the new version of 
LibreOffice.

Kind regards,

The LibreOffice Extension and Template Site Administration Team
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: Branch 'libreoffice-6-4' - connectivity/source

2020-03-08 Thread Julien Nabet (via logerrit)
 connectivity/source/drivers/firebird/DatabaseMetaData.cxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 92438b37a470b603642775fb44dc08b8f6b78042
Author: Julien Nabet 
AuthorDate: Sun Mar 8 13:58:35 2020 +0100
Commit: Lionel Elie Mamane 
CommitDate: Sun Mar 8 18:27:43 2020 +0100

tdf#131217: position arg in Blob::getBytes begins at 1 not 0 (Firebird)

See part of bt here:
https://bugs.documentfoundation.org/show_bug.cgi?id=131217#c5

According to:

https://cgit.freedesktop.org/libreoffice/core/commit/?id=38ce989b4f9d2aead097e5a2e95b819def7e2624
position can't be 0

Change-Id: Ia7bf973b820b8642b45eb0bbc125011cab99de9c
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90186
Tested-by: Jenkins
Reviewed-by: Julien Nabet 
(cherry picked from commit bb51f81507a405266d251297684bd3ab60998197)
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90036
Reviewed-by: Lionel Elie Mamane 

diff --git a/connectivity/source/drivers/firebird/DatabaseMetaData.cxx 
b/connectivity/source/drivers/firebird/DatabaseMetaData.cxx
index b2ca13fb56f3..3d0401678d60 100644
--- a/connectivity/source/drivers/firebird/DatabaseMetaData.cxx
+++ b/connectivity/source/drivers/firebird/DatabaseMetaData.cxx
@@ -1247,7 +1247,7 @@ uno::Reference< XResultSet > SAL_CALL 
ODatabaseMetaData::getColumns(
 if (xDescriptionBlob.is())
 {
 sal_Int32 aBlobLength = 
static_cast(xDescriptionBlob->length());
-aDescription = 
OUString(reinterpret_cast(xDescriptionBlob->getBytes(0, 
aBlobLength).getArray()),
+aDescription = 
OUString(reinterpret_cast(xDescriptionBlob->getBytes(1, 
aBlobLength).getArray()),
 aBlobLength,
 RTL_TEXTENCODING_UTF8);
 }
@@ -1414,7 +1414,7 @@ uno::Reference< XResultSet > SAL_CALL 
ODatabaseMetaData::getTables(
 // TODO: we should actually be using CLOB here instead.
 // However we haven't implemented CLOB yet, so use BLOB.
 sal_Int32 aBlobLength = 
static_cast(xBlob->length());
-sDescription = 
OUString(reinterpret_cast(xBlob->getBytes(0, aBlobLength).getArray()),
+sDescription = 
OUString(reinterpret_cast(xBlob->getBytes(1, aBlobLength).getArray()),
 aBlobLength,
 RTL_TEXTENCODING_UTF8);
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: Branch 'libreoffice-6-4' - vcl/unx

2020-03-08 Thread Julien Nabet (via logerrit)
 vcl/unx/gtk3/gtk3gtkinst.cxx |2 ++
 1 file changed, 2 insertions(+)

New commits:
commit 58bbb4dc19f939e1173b9c7ed93878a006311c4d
Author: Julien Nabet 
AuthorDate: Sun Mar 8 00:25:16 2020 +0100
Commit: Caolán McNamara 
CommitDate: Sun Mar 8 17:08:52 2020 +0100

tdf#131210: avoid infinite loop in 'Date acceptance patterns'

Change-Id: Ib049b5d44f91e2b36c068e1ef351ae81707d885e
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90035
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 

diff --git a/vcl/unx/gtk3/gtk3gtkinst.cxx b/vcl/unx/gtk3/gtk3gtkinst.cxx
index 256aacc6b888..41af4ee7cf62 100644
--- a/vcl/unx/gtk3/gtk3gtkinst.cxx
+++ b/vcl/unx/gtk3/gtk3gtkinst.cxx
@@ -7698,11 +7698,13 @@ public:
 
 virtual void replace_selection(const OUString& rText) override
 {
+disable_notify_events();
 gtk_editable_delete_selection(GTK_EDITABLE(m_pEntry));
 OString sText(OUStringToOString(rText, RTL_TEXTENCODING_UTF8));
 gint position = gtk_editable_get_position(GTK_EDITABLE(m_pEntry));
 gtk_editable_insert_text(GTK_EDITABLE(m_pEntry), sText.getStr(), 
sText.getLength(),
  &position);
+enable_notify_events();
 }
 
 virtual void set_position(int nCursorPos) override
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: vcl/unx

2020-03-08 Thread Caolán McNamara (via logerrit)
 vcl/unx/gtk3/gtk3gtkinst.cxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 0d81a613ef5af22253e51d9917c5d5c94d764456
Author: Caolán McNamara 
AuthorDate: Sun Mar 8 15:13:50 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Mar 8 17:08:32 2020 +0100

tdf#131223 let return deactive active popup

Change-Id: Ib116a1eb047aa9f1a5ca7a2ec9333a793addd304
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90188
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 

diff --git a/sw/source/core/fields/authfld.cxx 
b/sw/source/core/fields/authfld.cxx
index 6e0af56c4a51..018a6d4908f3 100644
--- a/sw/source/core/fields/authfld.cxx
+++ b/sw/source/core/fields/authfld.cxx
@@ -181,31 +181,23 @@ sal_uInt16 SwAuthorityFieldType::GetSequencePos(const 
SwAuthEntry* pAuthEntry,
 SwRootFrame const*const pLayout)
 {
 //find the field in a sorted array of handles,
-#if OSL_DEBUG_LEVEL > 0
-bool bCurrentFieldWithoutTextNode = false;
-#endif
 if(!m_SequArr.empty() && m_SequArr.size() != m_DataArr.size())
 DelSequenceArray();
 if(m_SequArr.empty())
 {
 IDocumentRedlineAccess const& 
rIDRA(m_pDoc->getIDocumentRedlineAccess());
+SwTOXInternational aIntl(m_eLanguage, SwTOIOptions::NONE, 
m_sSortAlgorithm);
 // sw_redlinehide: need 2 arrays because the sorting may be different,
 // if multiple fields refer to the same entry and first one is deleted
 std::vector> aSortArr;
 std::vector> aSortArrRLHidden;
-SwIterator aIter( *this );
-
-SwTOXInternational aIntl(m_eLanguage, SwTOIOptions::NONE, 
m_sSortAlgorithm);
-
-for( SwFormatField* pFormatField = aIter.First(); pFormatField; 
pFormatField = aIter.Next() )
+std::vector vFields;
+GatherFields(vFields);
+for(SwFormatField* pFormatField : vFields)
 {
 const SwTextField* pTextField = pFormatField->GetTextField();
 if(!pTextField || !pTextField->GetpTextNode())
 {
-#if OSL_DEBUG_LEVEL > 0
-if(pAuthEntry == 
static_cast(pFormatField->GetField())->GetAuthEntry())
-bCurrentFieldWithoutTextNode = true;
-#endif
 continue;
 }
 const SwTextNode& rFieldTextNode = pTextField->GetTextNode();
@@ -289,9 +281,6 @@ sal_uInt16 SwAuthorityFieldType::GetSequencePos(const 
SwAuthEntry* pAuthEntry,
 return i + 1;
 }
 }
-#if OSL_DEBUG_LEVEL > 0
-OSL_ENSURE(bCurrentFieldWithoutTextNode, "Handle not found");
-#endif
 return 0;
 }
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: connectivity/source

2020-03-08 Thread Julien Nabet (via logerrit)
 connectivity/source/drivers/firebird/DatabaseMetaData.cxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit bb51f81507a405266d251297684bd3ab60998197
Author: Julien Nabet 
AuthorDate: Sun Mar 8 13:58:35 2020 +0100
Commit: Julien Nabet 
CommitDate: Sun Mar 8 16:34:59 2020 +0100

tdf#131217: position arg in Blob::getBytes begins at 1 not 0 (Firebird)

See part of bt here:
https://bugs.documentfoundation.org/show_bug.cgi?id=131217#c5

According to:

https://cgit.freedesktop.org/libreoffice/core/commit/?id=38ce989b4f9d2aead097e5a2e95b819def7e2624
position can't be 0

Change-Id: Ia7bf973b820b8642b45eb0bbc125011cab99de9c
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90186
Tested-by: Jenkins
Reviewed-by: Julien Nabet 

diff --git a/connectivity/source/drivers/firebird/DatabaseMetaData.cxx 
b/connectivity/source/drivers/firebird/DatabaseMetaData.cxx
index 3fb6435f60be..32e397041d89 100644
--- a/connectivity/source/drivers/firebird/DatabaseMetaData.cxx
+++ b/connectivity/source/drivers/firebird/DatabaseMetaData.cxx
@@ -1248,7 +1248,7 @@ uno::Reference< XResultSet > SAL_CALL 
ODatabaseMetaData::getColumns(
 if (xDescriptionBlob.is())
 {
 sal_Int32 aBlobLength = 
static_cast(xDescriptionBlob->length());
-aDescription = 
OUString(reinterpret_cast(xDescriptionBlob->getBytes(0, 
aBlobLength).getArray()),
+aDescription = 
OUString(reinterpret_cast(xDescriptionBlob->getBytes(1, 
aBlobLength).getArray()),
 aBlobLength,
 RTL_TEXTENCODING_UTF8);
 }
@@ -1415,7 +1415,7 @@ uno::Reference< XResultSet > SAL_CALL 
ODatabaseMetaData::getTables(
 // TODO: we should actually be using CLOB here instead.
 // However we haven't implemented CLOB yet, so use BLOB.
 sal_Int32 aBlobLength = 
static_cast(xBlob->length());
-sDescription = 
OUString(reinterpret_cast(xBlob->getBytes(0, aBlobLength).getArray()),
+sDescription = 
OUString(reinterpret_cast(xBlob->getBytes(1, aBlobLength).getArray()),
 aBlobLength,
 RTL_TEXTENCODING_UTF8);
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: vcl/unx

2020-03-08 Thread Julien Nabet (via logerrit)
 vcl/unx/gtk3/gtk3gtkinst.cxx |2 ++
 1 file changed, 2 insertions(+)

New commits:
commit 3ddfba19c964a65a5bfa1c172e83532af305c985
Author: Julien Nabet 
AuthorDate: Sun Mar 8 00:25:16 2020 +0100
Commit: Caolán McNamara 
CommitDate: Sun Mar 8 15:15:11 2020 +0100

tdf#131210: avoid infinite loop in 'Date acceptance patterns'

Change-Id: Ib049b5d44f91e2b36c068e1ef351ae81707d885e
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90180
Tested-by: Jenkins
Tested-by: Caolán McNamara 
Reviewed-by: Caolán McNamara 

diff --git a/vcl/unx/gtk3/gtk3gtkinst.cxx b/vcl/unx/gtk3/gtk3gtkinst.cxx
index 10ddc6612ec9..f589667bd4e4 100644
--- a/vcl/unx/gtk3/gtk3gtkinst.cxx
+++ b/vcl/unx/gtk3/gtk3gtkinst.cxx
@@ -8339,11 +8339,13 @@ public:
 
 virtual void replace_selection(const OUString& rText) override
 {
+disable_notify_events();
 gtk_editable_delete_selection(GTK_EDITABLE(m_pEntry));
 OString sText(OUStringToOString(rText, RTL_TEXTENCODING_UTF8));
 gint position = gtk_editable_get_position(GTK_EDITABLE(m_pEntry));
 gtk_editable_insert_text(GTK_EDITABLE(m_pEntry), sText.getStr(), 
sText.getLength(),
  &position);
+enable_notify_events();
 }
 
 virtual void set_position(int nCursorPos) override
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: Branch 'libreoffice-6-4' - sd/source sd/uiconfig

2020-03-08 Thread Julien Nabet (via logerrit)
 sd/source/ui/dlg/tpoption.cxx|   12 
 sd/source/ui/inc/tpoption.hxx|2 +-
 sd/uiconfig/simpress/ui/optimpressgeneralpage.ui |4 ++--
 3 files changed, 11 insertions(+), 7 deletions(-)

New commits:
commit f96d0ae4a0e768995ce5a27ccc524112163dff80
Author: Julien Nabet 
AuthorDate: Thu Mar 5 18:40:42 2020 +0100
Commit: Caolán McNamara 
CommitDate: Sun Mar 8 15:13:21 2020 +0100

tdf#131137: Fix Checkbox "Do not distort objects in curve" does nothing

includes too:

https://cgit.freedesktop.org/libreoffice/core/commit/?id=9e8839c934da9744b8f584debc0ad026e49f4a28
which was just an oops.

See https://bugs.documentfoundation.org/show_bug.cgi?id=131137#c3
and above all
https://bugs.documentfoundation.org/show_bug.cgi?id=131137#c4

Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90054
Tested-by: Jenkins
Reviewed-by: Julien Nabet 
(cherry picked from commit 6d9930f307f08d2c32ee1bcca577cf643955cec9)

Change-Id: Ibd38d13be7ef6956d6c26e6f5f71a6751a56b25e
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90029
Tested-by: Caolán McNamara 
Reviewed-by: Caolán McNamara 

diff --git a/sd/source/ui/dlg/tpoption.cxx b/sd/source/ui/dlg/tpoption.cxx
index 2adcd977111f..2331510efb5c 100644
--- a/sd/source/ui/dlg/tpoption.cxx
+++ b/sd/source/ui/dlg/tpoption.cxx
@@ -198,7 +198,7 @@ SdTpOptionsMisc::SdTpOptionsMisc(weld::Container* pPage, 
weld::DialogController*
 , m_xHeightLb(m_xBuilder->weld_label("heightlbl"))
 , m_xFiInfo2(m_xBuilder->weld_label("info2"))
 , 
m_xMtrFldOriginalHeight(m_xBuilder->weld_metric_spin_button("metricHeightFields",
 FieldUnit::MM))
-, m_xCbxDistrot(m_xBuilder->weld_check_button("distrotcb"))
+, m_xCbxDistort(m_xBuilder->weld_check_button("distortcb"))
 , m_xMtrFldInfo1(m_xBuilder->weld_metric_spin_button("metricInfo1Fields", 
FieldUnit::MM))
 , m_xMtrFldInfo2(m_xBuilder->weld_metric_spin_button("metricInfo2Fields", 
FieldUnit::MM))
 {
@@ -219,7 +219,7 @@ SdTpOptionsMisc::SdTpOptionsMisc(weld::Container* pPage, 
weld::DialogController*
 SetFieldUnit( *m_xMtrFldTabstop , eFUnit );
 
 // Impress is default mode, let' hide the entire scale frame etc.
-m_xCbxDistrot->hide();
+m_xCbxDistort->hide();
 m_xScaleFrame->hide();
 
 // fill ListBox with metrics
@@ -342,7 +342,8 @@ bool SdTpOptionsMisc::FillItemSet( SfxItemSet* rAttrs )
 m_xCbxEnableSdremote->get_state_changed_from_saved()||
 m_xCbxEnablePresenterScreen->get_state_changed_from_saved() ||
 m_xCbxCompatibility->get_state_changed_from_saved() ||
-m_xCbxUsePrinterMetrics->get_state_changed_from_saved() )
+m_xCbxUsePrinterMetrics->get_state_changed_from_saved() ||
+m_xCbxDistort->get_state_changed_from_saved())
 {
 SdOptionsMiscItem aOptsItem;
 
@@ -359,6 +360,7 @@ bool SdTpOptionsMisc::FillItemSet( SfxItemSet* rAttrs )
 m_xCbxUsePrinterMetrics->get_active()
 ? css::document::PrinterIndependentLayout::DISABLED
 : css::document::PrinterIndependentLayout::ENABLED);
+aOptsItem.GetOptionsMisc().SetCrookNoContortion( 
m_xCbxDistort->get_active() );
 rAttrs->Put( aOptsItem );
 
 bModified = true;
@@ -410,6 +412,7 @@ void SdTpOptionsMisc::Reset( const SfxItemSet* rAttrs )
 m_xCbxEnablePresenterScreen->set_active( 
aOptsItem.GetOptionsMisc().IsEnablePresenterScreen() );
 m_xCbxCompatibility->set_active( 
aOptsItem.GetOptionsMisc().IsSummationOfParagraphs() );
 m_xCbxUsePrinterMetrics->set_active( 
aOptsItem.GetOptionsMisc().GetPrinterIndependentLayout()==1 );
+m_xCbxDistort->set_active( 
aOptsItem.GetOptionsMisc().IsCrookNoContortion() );
 m_xCbxStartWithTemplate->save_state();
 m_xCbxMarkedHitMovesAlways->save_state();
 m_xCbxQuickEdit->save_state();
@@ -421,6 +424,7 @@ void SdTpOptionsMisc::Reset( const SfxItemSet* rAttrs )
 m_xCbxEnablePresenterScreen->save_state();
 m_xCbxCompatibility->save_state();
 m_xCbxUsePrinterMetrics->save_state();
+m_xCbxDistort->save_state();
 
 // metric
 sal_uInt16 nWhich = GetWhich( SID_ATTR_METRIC );
@@ -519,7 +523,7 @@ void SdTpOptionsMisc::SetDrawMode()
 m_xMtrFldOriginalWidth->show();
 m_xFiInfo2->show();
 m_xMtrFldOriginalHeight->show();
-m_xCbxDistrot->show();
+m_xCbxDistort->show();
 m_xCbxCompatibility->hide();
 }
 
diff --git a/sd/source/ui/inc/tpoption.hxx b/sd/source/ui/inc/tpoption.hxx
index 1cc5a88f2ffa..d66a5317e6b1 100644
--- a/sd/source/ui/inc/tpoption.hxx
+++ b/sd/source/ui/inc/tpoption.hxx
@@ -102,7 +102,7 @@ private:
 std::unique_ptr m_xHeightLb;
 std::unique_ptr m_xFiInfo2;
 std::unique_ptr m_xMtrFldOriginalHeight;
-std::unique_ptr m_xCbxDistrot;
+std::unique_ptr m_xCbxDistort;
 std::unique_ptr m_xMtrFldInfo1;
 std::unique_ptr m_xMtrFldInfo2;
 
diff --git a/sd/uiconfig/si

[Libreoffice-commits] core.git: lotuswordpro/source

2020-03-08 Thread Caolán McNamara (via logerrit)
 lotuswordpro/source/filter/lwprowlayout.cxx |5 -
 1 file changed, 4 insertions(+), 1 deletion(-)

New commits:
commit 17cf56c127351ff61aeb75e84dfa884492f5252d
Author: Caolán McNamara 
AuthorDate: Sat Mar 7 19:11:06 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Mar 8 15:08:26 2020 +0100

ofz#20635 infinite loop

Change-Id: I7b40df05307e3dd7768e9407040eb4fa285d51e1
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90174
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 

diff --git a/lotuswordpro/source/filter/lwprowlayout.cxx 
b/lotuswordpro/source/filter/lwprowlayout.cxx
index 811b7abb762e..2cc3bd59bbf9 100644
--- a/lotuswordpro/source/filter/lwprowlayout.cxx
+++ b/lotuswordpro/source/filter/lwprowlayout.cxx
@@ -403,7 +403,10 @@ void 
LwpRowLayout::ConvertCommonRow(rtl::Reference const & pXFTable, sa
 if (pCellLayout->GetLayoutType() == LWP_CONNECTED_CELL_LAYOUT)
 {
 LwpConnectedCellLayout* pConnCell = 
static_cast(pCellLayout);
-nCellEndCol = i+pConnCell->GetNumcols()-1;
+auto nNumCols = pConnCell->GetNumcols();
+if (!nNumCols)
+throw std::runtime_error("loop in conversion");
+nCellEndCol = i + nNumCols - 1;
 i = nCellEndCol;
 }
 xCell = 
pCellLayout->DoConvertCell(pTable->GetObjectID(),crowid,i);
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: include/vcl

2020-03-08 Thread Caolán McNamara (via logerrit)
 include/vcl/BitmapTools.hxx |3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

New commits:
commit 1e95c2c17a49349caba1e62b4de3752c5f767f01
Author: Caolán McNamara 
AuthorDate: Sat Mar 7 19:24:42 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Mar 8 15:08:10 2020 +0100

ofz#20622 oom

Change-Id: Id77d90197e98d29787a40966f248dd769c9dac28
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90175
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 

diff --git a/include/vcl/BitmapTools.hxx b/include/vcl/BitmapTools.hxx
index 4e3efbcef84f..6d7c8c930472 100644
--- a/include/vcl/BitmapTools.hxx
+++ b/include/vcl/BitmapTools.hxx
@@ -53,7 +53,8 @@ public:
 assert(nBitCount == 24 || nBitCount == 32);
 sal_Int32 nRowSize, nDataSize;
 if (o3tl::checked_multiply(rSize.getWidth(), nBitCount/8, 
nRowSize) ||
-o3tl::checked_multiply(nRowSize, rSize.getHeight(), 
nDataSize))
+o3tl::checked_multiply(nRowSize, rSize.getHeight(), 
nDataSize) ||
+nDataSize < 0)
 {
 throw std::bad_alloc();
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: status of --enable-split-debug ?

2020-03-08 Thread Terrence Enger
On Sun, 2020-03-08 at 13:29 +0100, Luboš Luňák wrote:
> On Sunday 08 of March 2020, Terrence Enger wrote:
> > Hello, All,
> > 
> > I think that sometime between 2020-02-15 and 2020-02-20 my local
> > build with parameter --enable-split-debug stopped showing debug
> > symbols in gdb.  I presume that this was not an intentional change.
> 
>  It works fine for me. Given that it is the default for debug builds and it's 
> been more than 2 weeks for other people to notice, maybe rather something 
> else has changed for you?
> 

Yeah, I guess so.  This is one of the times that I hate computers.

Thank you confirming my suspicion.
Terry.


___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: include/drawinglayer

2020-03-08 Thread Andrea Gelmini (via logerrit)
 include/drawinglayer/geometry/viewinformation2d.hxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 9042e7ebaf0f77393cfbb72fe299d4fe524bd689
Author: Andrea Gelmini 
AuthorDate: Sun Mar 8 00:13:55 2020 +0100
Commit: Adolfo Jayme Barrientos 
CommitDate: Sun Mar 8 13:30:37 2020 +0100

Fix typo

Change-Id: Icb3c9deb140b119311066784157da413f686aba3
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90178
Reviewed-by: Adolfo Jayme Barrientos 
Tested-by: Adolfo Jayme Barrientos 

diff --git a/include/drawinglayer/geometry/viewinformation2d.hxx 
b/include/drawinglayer/geometry/viewinformation2d.hxx
index 4c73d5d02be5..95be29a72bda 100644
--- a/include/drawinglayer/geometry/viewinformation2d.hxx
+++ b/include/drawinglayer/geometry/viewinformation2d.hxx
@@ -112,7 +112,7 @@ public:
 
 @param rViewParameters
 A sequence of property values which allows holding any combination of 
local and various
-other parameters. This constructor is feeded completely with a 
sequence of PropertyValues
+other parameters. This constructor is fed completely with a sequence 
of PropertyValues
 which will be parsed to be able to offer the most used ones in a 
convenient way.
 */
 explicit ViewInformation2D(
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


Re: status of --enable-split-debug ?

2020-03-08 Thread Luboš Luňák
On Sunday 08 of March 2020, Terrence Enger wrote:
> Hello, All,
>
> I think that sometime between 2020-02-15 and 2020-02-20 my local
> build with parameter --enable-split-debug stopped showing debug
> symbols in gdb.  I presume that this was not an intentional change.

 It works fine for me. Given that it is the default for debug builds and it's 
been more than 2 weeks for other people to notice, maybe rather something 
else has changed for you?

-- 
 Luboš Luňák
 l.lu...@collabora.com
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: connectivity/source

2020-03-08 Thread Julien Nabet (via logerrit)
 connectivity/source/drivers/firebird/User.cxx |   12 
 connectivity/source/drivers/firebird/User.hxx |4 
 2 files changed, 16 insertions(+)

New commits:
commit b262b973ad1e3cb5c7b89842fc7566bc8715d34f
Author: Julien Nabet 
AuthorDate: Sun Mar 8 10:21:33 2020 +0100
Commit: Julien Nabet 
CommitDate: Sun Mar 8 12:28:13 2020 +0100

tdf#131219: workaround for getPrivilege/getGrantablePrivileges in Firebird

It must really be implemented. Meanwhile, let's avoid the error popups.

Change-Id: If78e7d1b955ba70fd5ad282ba12b26806b7c81b0
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90184
Tested-by: Jenkins
Reviewed-by: Julien Nabet 

diff --git a/connectivity/source/drivers/firebird/User.cxx 
b/connectivity/source/drivers/firebird/User.cxx
index a2e6f71e3bed..3a9682fb8264 100644
--- a/connectivity/source/drivers/firebird/User.cxx
+++ b/connectivity/source/drivers/firebird/User.cxx
@@ -32,6 +32,18 @@ void User::changePassword(const OUString&, const OUString& 
newPassword)
 m_xConnection->createStatement()->execute("ALTER USER " + m_Name + " 
PASSWORD '" + newPassword + "'");
 }
 
+sal_Int32 User::getPrivileges(const OUString& , sal_Int32 )
+{
+// TODO: implement.
+return 0;
+}
+
+sal_Int32 User::getGrantablePrivileges(const OUString& , sal_Int32 )
+{
+// TODO: implement.
+return 0;
+}
+
 //- IRefreshableGroups 
 void User::refreshGroups()
 {
diff --git a/connectivity/source/drivers/firebird/User.hxx 
b/connectivity/source/drivers/firebird/User.hxx
index fe2f97dcdb54..5668c3223c13 100644
--- a/connectivity/source/drivers/firebird/User.hxx
+++ b/connectivity/source/drivers/firebird/User.hxx
@@ -35,7 +35,11 @@ namespace connectivity
  */
 User(const css::uno::Reference< css::sdbc::XConnection >& 
rConnection, const OUString& rName);
 
+// XAuthorizable
 virtual void SAL_CALL changePassword(const OUString&, const 
OUString& newPassword) override;
+virtual sal_Int32 SAL_CALL getPrivileges(const OUString&, 
sal_Int32) override;
+virtual sal_Int32 SAL_CALL getGrantablePrivileges(const OUString&, 
sal_Int32) override;
+
 // IRefreshableGroups::
 virtual void refreshGroups() override;
 };
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits
diff --git a/vcl/unx/gtk3/gtk3gtkinst.cxx b/vcl/unx/gtk3/gtk3gtkinst.cxx
index f589667bd4e4..202b5f4c1c10 100644
--- a/vcl/unx/gtk3/gtk3gtkinst.cxx
+++ b/vcl/unx/gtk3/gtk3gtkinst.cxx
@@ -12397,8 +12397,8 @@ private:
 case KEY_RIGHT:
 case KEY_RETURN:
 m_aQuickSelectionEngine.Reset();
-// tdf#131076 don't let bare return toggle menu popup
-if (nCode == KEY_RETURN && !pEvent->state)
+// tdf#131076 don't let bare return toggle menu popup active, 
but do allow deactive
+if (nCode == KEY_RETURN && !pEvent->state && !m_bPopupActive)
 bDone = combobox_activate();
 break;
 default:
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sw/source

2020-03-08 Thread Bjoern Michaelsen (via logerrit)
 sw/source/core/fields/authfld.cxx |   19 ---
 1 file changed, 4 insertions(+), 15 deletions(-)

New commits:
commit 6a2958f3d91af30a93f0b8726eba626d809186b0
Author: Bjoern Michaelsen 
AuthorDate: Sat Mar 7 16:49:42 2020 +0100
Commit: Björn Michaelsen 
CommitDate: Sun Mar 8 17:05:49 2020 +0100

SwAuthorityFieldType::GetSequencePos(): SwIterator no more ...

Change-Id: Ibe6b2d2f534fad296c46ef6c3c18c63ccbf265e2
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/90170
Tested-by: Jenkins
Reviewed-by: Björn Michaelsen 
